%define ALD_Ver		1.2.1

Name:         nfs-utils

License:      GPLv2
Summary:      Linux NFS utility package.
Group:        System Environment/Daemons
Version:      1.2.6
Release:      1

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh
Patch0: nfs-utils-1.2.6.patch

%define DestDir		/net

# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%else
# rpm --target=x86_64/armv6l/win32 -ba xxxxx.spec
%define _CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
ERROR: target=%{_os}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define cross_bindir	%{csysdir}%{_bindir}
%define cross_sbindir	%{csysdir}%{_sbindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{name}

%define CrossDestDir	/Cross

%define _srcrpmdir	%{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysbindir	%{_prefix}/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target_  %{nil}
%define target %{_build}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}

# ------------------- description ------------------------------------
%description
This is version %{version} of nfs-utils, the Linux NFS utility package.
#-------------------------------
%package python
Summary:      python for %{name}
Group:        Development/Tools
%description python
python for %{name}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}
%patch0 -b .orig -p0

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2 -fno-asynchronous-unwind-tables"
%endif
%if %{_arch} == "arm"
OPTFLAGS="-O2 -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif

CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections"
LDFLAGS="-Wl,--gc-sections"

CONFIG_SQLITE3_TRUE='#'
CONFIG_NFSDCLD_TRUE='#'
export CONFIG_SQLITE3_TRUE CONFIG_NFSDCLD_TRUE

sed -i s:"@CFLAGS@":"-O2": tools/locktest/Makefile.in
sed -i s:"@CFLAGS@":"-O2": tools/rpcdebug/Makefile.in
sed -i s:"@CFLAGS@":"-O2": tools/rpcgen/Makefile.in

%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
	--disable-libtool-lock \
	--disable-gss \
	--disable-uuid \
	--disable-tirpc \
	--enable-mountconfig \
	--disable-nfsdcld \
	--with-rpcgen=internal \
	&>FConfigure_log.txt

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/usr
mkdir -p $RPM_BUILD_ROOT/sbin
mkdir -p $RPM_BUILD_ROOT%{docdir}
mkdir -p $RPM_BUILD_ROOT/var/lib/nfs/v4recovery
mkdir -p %{_srcrpmdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt

rm -rf $RPM_BUILD_ROOT%{_sbindir}/rpcdebug

cp COPYING NEWS README $RPM_BUILD_ROOT%{docdir}/

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=0
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%endif #_CROSS

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}
DEC=%{version}-%{release}.%{_build_cpu}.rpm
DDC=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-python-$SE $DD/%{name}-python-$DE
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
popd
%endif  #BUILD_TAR

%post
if [ ! -e /etc/exports ]; then
  cat > /etc/exports <<EOF
# Please read the manual page exports(5) for more information.

# sample /etc/exports file

#/tmp            *(ro,all_squash,subtree_check)
#/               master(rw) trusty(rw,no_root_squash)
#/projects       proj*.local.domain(rw)
#/usr            *.local.domain(ro) @trusted(rw)
#/home/joe       pc001(rw,all_squash,anonuid=150,anongid=100)
#/pub            *(ro,insecure,all_squash)
#/srv/www        -sync,rw server @trusted @external(ro)
/                192.168.*.*(ro,no_subtree_check,no_root_squash)

EOF
fi

if [ ! -e /etc/nfsmount.conf ]; then
  cat > /etc/nfsmount.conf <<EOF
#
# /etc/nfsmount.conf - see nfsmount.conf(5) for details
#
# This is an NFS mount configuration file. This file can be broken
# up into three different sections: Mount, Server and Global
# 
# [ MountPoint "Mount_point" ] 
# This section defines all the mount options that
# should be used on a particular mount point. The '<Mount_Point>'
# string need to be an exact match of the path in the mount 
# command. Example:
#     [ MountPoint "/export/home" ]
#       background=True
# Would cause all mount to /export/home would be done in
# the background
#
# [ Server "Server_Name" ]
# This section defines all the mount options that
# should be used on mounts to a particular NFS server. 
# Example:
#     [ Server "nfsserver.foo.com" ]
#       rsize=32k
#       wsize=32k
# All reads and writes to the 'nfsserver.foo.com' server 
# will be done with 32k (32768 bytes) block sizes.
#
[ NFSMount_Global_Options ]
# This statically named section defines global mount 
# options that can be applied on all NFS mount.
#
# Protocol Version [2,3,4]
# This defines the default protocol version which will
# be used to start the negotiation with the server.
# Defaultvers=4
#
# Setting this option makes it mandatory the server supports the
# given version. The mount will fail if the given version is 
# not support by the server. 
# Nfsvers=4
#
# Network Protocol [udp,tcp,rdma] (Note: values are case sensitive)
# This defines the default network protocol which will
# be used to start the negotiation with the server.
# Defaultproto=tcp
#
# Setting this option makes it mandatory the server supports the
# given network protocol. The mount will fail if the given network
# protocol is not supported by the server.
# Proto=tcp
#
# The number of times a request will be retired before 
# generating a timeout 
# Retrans=2
#
# The number of minutes that will retry mount
# Retry=2
#
# The minimum time (in seconds) file attributes are cached
# acregmin=30
#
# The Maximum time (in seconds) file attributes are cached
# acregmin=60
#
# The minimum time (in seconds) directory attributes are cached
# acregmin=30
#
# The Maximum time (in seconds) directory attributes are cached
# acregmin=60
#
# Enable Access  Control  Lists
# Acl=False
#
# Enable Attribute Caching
# Ac=True
#
# Do mounts in background (i.e. asynchronously)
# Background=False
#
# Close-To-Open cache coherence
# Cto=True
#
# Do mounts in foreground (i.e. synchronously)
# Foreground=True
#
# How to handle times out from servers (Hard is STRONGLY suggested)
# Hard=True
# Soft=False
#
# Enable File Locking
# Lock=True
#
# Enable READDIRPLUS on NFS version 3 mounts
# Rdirplus=True
#
# Maximum Read Size (in Bytes)
# Rsize=8k
#
# Maximum Write Size (in Bytes)
# Wsize=8k
#
# Maximum Server Block Size (in Bytes)
# Bsize=8k
#
# Ignore unknown mount options
# Sloppy=False
#
# Share Data and Attribute Caches
# Sharecache=True
#
# The amount of time, in tenths of a seconds, the client
# will wait for a response from the server before retransmitting
# the request.
# Timeo=600
#
# Sets all attributes times to the same time (in seconds)
# actimeo=30
#
# Server Mountd port mountport
# mountport=4001
#
# Server Mountd Protocol
# mountproto=tcp
#
# Server Mountd Version
# mounvers=3
#
# Server Mountd Host
# mounthost=hostname
#
# Server Port
# Port=2049
#
# RPCGSS security flavors 
# [none, sys, krb5, krb5i, krb5p ]
# Sec=sys
EOF
fi

if [ ! -e /etc/init.d/nfsd ]; then
  cat > /etc/init.d/nfsd <<EOF
#!/bin/bash

. /etc/colorrc

test -f /etc/aldccp/network || exit 0
. /etc/aldccp/network

test ! x\$NETWORKING = x"yes" && exit 0
test ! x\$PORTMAP_START = x"yes" && exit 0
test ! x\$NFSD_START = x"yes" && exit 0

test -f /usr/sbin/exportfs || exit 0
test -f /usr/sbin/rpc.mountd || exit 0
test -f /usr/sbin/rpc.statd || exit 0
test -f /usr/sbin/rpc.nfsd || exit 0

case "\$1" in
    start)
	if ! checkproc /sbin/portmap; then
	    echo "/sbin/portmap: is not running \$rc_Err"
	    exit 1
	fi

	echo -n "Starting exportfs... "
	exportfs -a
	if test \$? != 0; then
	    echo "\$rc_Err"
	    exit 1
	fi
	echo "\$rc_Ok"

	if test ! -f /proc/fs/nfsd/versions; then
	    modprobe -q sunrpc
	    modprobe -q nfsd
	    mount -t nfsd nfsd /proc/fs/nfsd
	fi

	if ! checkproc /usr/sbin/rpc.mountd; then
	    echo -n "Starting rpc.mountd daemon... "
	    rpc.mountd
	    if test \$? != 0; then
		echo "\$rc_Err"
		exit 1
	    fi
	    echo "\$rc_Ok"
	fi

	if ! checkproc /usr/sbin/rpc.statd; then
	    echo -n "Starting rpc.statd daemon... "
	    rpc.statd --no-notify
	    if test \$? != 0; then
		echo "\$rc_Err"
		exit 1
	    fi
	    echo "\$rc_Ok"
	fi

	echo -n "Starting rpc.nfsd daemon... "
	rpc.nfsd --port 2049 1
	if test \$? != 0; then
	    echo "\$rc_Err"
	    exit 1
	fi
	echo "\$rc_Ok"

	sm-notify

	;;
    stop)
	echo -n "Shut Down rpc.nfsd daemon... "
	rpc.nfsd 0
	if test \$? != 0; then
	    echo "\$rc_Err"
	else
	    echo "\$rc_Ok"
	fi

	if checkproc /usr/sbin/rpc.statd; then
	    echo -n "Shut Down rpc.statd daemon... "
	    killproc rpc.statd
	    if test \$? != 0; then
		echo "\$rc_Err"
	    else
		echo "\$rc_Ok"
	    fi
	fi
	if checkproc /usr/sbin/rpc.mountd; then
	    echo -n "Shut Down rpc.mountd daemon... "
	    killproc rpc.mountd
	    if test \$? != 0; then
		echo "\$rc_Err"
	    else
		echo "\$rc_Ok"
	    fi
	fi
	;;
    restart)
	\$0 stop
	\$0 start
	;;
    *)
	echo "Usage: {start|stop|restart}"
	exit 1
	;;
esac

exit 0

EOF

chmod 0740 /etc/init.d/nfsd

pushd /etc/init.d/rc_net >/dev/null
  ln -s ../nfsd K10nfsd
  ln -s ../nfsd S82nfsd
popd >/dev/null

fi

if [ ! -e /etc/init.d/nfs ]; then
  cat > /etc/init.d/nfs <<EOF
#!/bin/bash

. /etc/colorrc

test -f /etc/aldccp/network || exit 0
. /etc/aldccp/network

test ! x\$NETWORKING = x"yes" && exit 0
test ! x\$PORTMAP_START = x"yes" && exit 0
test ! x\$NFS_START = x"yes" && exit 0

test -f /usr/sbin/rpc.statd || exit 0

case "\$1" in
    start)
	if ! checkproc /sbin/portmap; then
	    echo "/sbin/portmap: is not running \$rc_Err"
	    exit 1
	fi

	sm-notify

	if ! checkproc /usr/sbin/rpc.statd; then
	    echo -n "Starting rpc.statd daemon... "
	    rpc.statd --no-notify
	    if test \$? != 0; then
		echo "\$rc_Err"
		exit 1
	    fi
	    echo "\$rc_Ok"
	fi
	;;

    stop)

	if checkproc /usr/sbin/rpc.statd; then
	    echo -n "Shut Down rpc.statd daemon... "
	    killproc rpc.statd
	    if test \$? != 0; then
		echo "\$rc_Err"
	    else
		echo "\$rc_Ok"
	    fi
	fi
	;;
    restart)
	\$0 stop
	\$0 start
	;;
    *)
	echo "Usage: {start|stop|restart}"
	exit 1
	;;
esac

exit 0

EOF

chmod 0740 /etc/init.d/nfs

pushd /etc/init.d/rc_net >/dev/null
  ln -s ../nfs K11nfs
  ln -s ../nfs S83nfs
popd >/dev/null

fi

# ------------------- Files ------------------------------------------
%Files
/sbin
%{_sbindir}
%exclude %{_sbindir}/mountstats
%exclude %{_sbindir}/nfsiostat
%{_mandir}
%exclude %{_mandir}/man8/mountstats.8.gz
%exclude %{_mandir}/man8/nfsiostat.8.gz
/var
%{docdir}

%files python
%{_sbindir}/mountstats
%{_sbindir}/nfsiostat
%{_mandir}/man8/mountstats.8.gz
%{_mandir}/man8/nfsiostat.8.gz
